@@ -4,6 +4,8 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
                      nb.ellip = 100, graph= TRUE, axes = c(1, 2), label.group=NULL) 
 {
 
+  
+  stop("Pendiente de revision")
   # ncp= number of dimensions kept to compute (by default NULL to indicate all dimensions)
   ncp <- NULL
   
@@ -19,7 +21,13 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
   if(!is.null(object$var.agg)) stop("LexGalt needs non aggregate TextData objects")
   options(stringsAsFactors = FALSE)
   
-  Xtab.disjonctif <- function(tab)
+  
+  
+  
+##################################################
+### Fase 0. Funciones
+#################################################  
+    Xtab.disjonctif <- function(tab)
   {
     tab <- as.data.frame(tab,  stringsAsFactors = TRUE)
     modalite.disjonctif <- function(i) {
@@ -36,8 +44,7 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
     else {
       variable <- rep(attributes(tab)$names, lapply(tab, nlevels))
       listModa <- unlist(lapply(tab, levels))
-      wlistModa <- which((listModa) %in% c("y", "n", 
-                                           "Y", "N"))
+      wlistModa <- which((listModa) %in% c("y", "n","Y", "N"))
       if (!is.null(wlistModa)) 
         listModa[wlistModa] <- paste(variable[wlistModa], 
                                      listModa[wlistModa], sep = ".")
@@ -52,12 +59,15 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
     return(res)
   }
 
-
-    #######################################################################
-  # 1.- Checking if it is a list (multiple) or only one object (simple)
+  mean.p<-function(V, poids) res <- sum(V * poids, na.rm = TRUE)/sum(poids[!is.na(V)])
+  sd.p<-function(V, poids) res <- sqrt(sum(V^2 * poids, na.rm = TRUE)/sum(poids[!is.na(V)]))
+  #######################################################################
+  
+  
+  #######################################################################
+  # FASE 1. - Checking if it is a list (multiple) or only one object (simple)
   num.group <- ifelse(is.vector(object), length(object),1)
   
-
   if(num.group==1) {
     # Simple, only one TextData object
     # If it is not a TextData object: stop
@@ -70,8 +80,11 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
   }
   #######################################################################
   
+  
+  
+  
   #######################################################################
-  ##2. Contextual variables
+  ## FASE 2. Contextual variables
   context.quanti <- context.quali <- NULL
   #############  Start selecting contextual variables	
   if(length(context)==1)	# Only one contextual variable
@@ -117,14 +130,12 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
   
   
   
-  #######################################################################
-  ##3. Functions
-  mean.p<-function(V, poids) res <- sum(V * poids, na.rm = TRUE)/sum(poids[!is.na(V)])
-  sd.p<-function(V, poids) res <- sqrt(sum(V^2 * poids, na.rm = TRUE)/sum(poids[!is.na(V)]))
+  
+  
   
 
   #######################################################################
-  ## 4. Simple LexGalt 
+  ## FASE 3. Simple LexGalt 
   ####### If LexGalt is simple, not multiple
   if(num.group==1) {  # It is simple, not multiple
     
@@ -165,41 +176,47 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
     
     if(nQN+nQL==0) stop("There are not contextual variables")
     
+   
+     
+    
     ##############################################
-    # 5.  Starting 
+    # FASE 5.  Starting 
     Y <- as.matrix(object$DocTerm) # (Documents x words) (Respondents x words)
     P <- as.matrix(Y/sum(Y))       # Proportion matrix 
     PI. <- apply(P, 1, sum)        # Margin vector % words for each document (respondent)
     P.J <- apply(P, 2, sum)        # Margin vector % words for each word
     # I respondents (docs), J words, K quantitative variables (nQN)
-    ##############################################  
+    ##############################################
     
     
+    ####################################
+    ### Fase 6 #########################
     ########### Start funct1 ############					
-    funct1 <- function(phi.stand,ncpf,XP,su) {					
+    funct1 <- function(phi.stand,ncpf,XP,su) {					# Quanti or qualitative variables
+      # phi.stand have the eigenvectors (docs x dimensiones)
       # su: scale. TRUE if quantitative scaled 
-      # su: is FALSE if qualitative or quantitative not scaled (centered)
+      # su: if FALSE. If qualitative or quantitative variables they are not scaled (yes centered)
       # P is not passed because is always the same 
       # P is % words in matrix documents x words
-      # phi.stand have the eigenvectors (docs x dimensiones)
       # ncpf is the number of factors
       # XP is the quantitative data matrix centered (and scaled if su=TRUE)
       # L Matrix (words x dimensions)
       # L <- t(P) *phi.stand/P.J  
-      L <- sweep(crossprod(P, phi.stand), 1, P.J, "/")					
+      L <- sweep(crossprod(P, phi.stand), 1, P.J, "/")
       # mT (Words x categories):  (J words x I docs) * (I docs x variables o categorías) 
       mT <- crossprod(P, XP)	
       C <- crossprod(sweep(XP, 1, PI.^(1/2), "*"), sweep(XP, 1, PI.^(1/2),"*"))	
       # J words x L variables or categories
       W <- sweep(crossprod(t(mT), MASS::ginv(C)), 1, P.J, "/")	
-      colnames(W) <- colnames(mT)
+            colnames(W) <- colnames(mT)
       # PCA using L as actif and W as supplementary
       diag.L <- PCA(cbind(L, W), quanti.sup = (ncpf + 1):(ncpf + ncol(mT)),
                     scale.unit = FALSE, ncp = ncpf, row.w = P.J, graph = FALSE)
-      # Document coordinates					
+      # Document coordinates		
       coord.ind <- sweep(crossprod(t(P), diag.L$svd$U), 1, PI., "/")
       # Cos2 of documents
       cos2.ind <- sweep(coord.ind^2, 1, apply(coord.ind^2, 1, sum),"/")
+      return(coord.ind)
       # Building an object res.doc with coordinates and cos2 for the documents
       res.doc <- list(coord = coord.ind, cos2 = cos2.ind)
       # Building an object res.word with coordinates and cos2 for the docs
@@ -211,7 +228,9 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
 
     
     
-    # =======  Call when LexGalt with quantitative variables			
+    
+    ############################################################################
+    # =======  FASE 7. Call when LexGalt has quantitative variables			
     if(nQN!=0) {			
       diag.XQN <- PCA(XQN, scale.unit = scale, ncp = ncpQN, row.w = PI., graph = FALSE)
       # phi.stand.QN has the eigenvectors (Docs x dimensions)
@@ -222,6 +241,7 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
       # If scale=TRUE divided for standard deviation
       if (scale == "TRUE") XQN <- sweep(XQN, 2, apply(XQN, 2, sd.p, PI.), "/")	
       resQN <- funct1(phi.stand.QN, ncpQN, XQN, scale)
+      return(resQN)
       resQN$quanti.var <- resQN$diag.L$quanti.sup	
       #  }
       class(resQN) <- c("LexGalt", "list")
@@ -653,4 +673,4 @@ LexGalt <- function (object, context="ALL", conf.ellip=FALSE,
      return(resNew)
    } # Final multiple or simple, if(num.group==1)
   
-} # Final LexGalt
\ No newline at end of file
+} # Final LexGalt
